MTfit.algorithms
================


.. automodule:: MTfit.algorithms

Contents
***********
.. toctree::
   :maxdepth: 1

   MTfit.algorithms.base<source-base>
   MTfit.algorithms.monte_carlo<source-monte_carlo>
   MTfit.algorithms.markov_chain_monte_carlo<source-markov_chain_monte_carlo>
